@@ -2,7 +2,7 @@
 
 from cmdMenuFramework.Printer import Printer
 from cmdMenuFramework.Context import Context
-from cmdMenuFramework.instruction.Instruction import Instruction
+from cmdMenuFramework.Instruction import Instruction
 import yaml
 
 class Menu:
