@@ -1,5 +1,5 @@
 
-from cmdMenuFramework.instruction.InstType import InstType
+from cmdMenuFramework.InstType import InstType
 
 class Path:
     
